# get_cached_nodes { #vscodenb.get_cached_nodes }

```python
vscodenb.get_cached_nodes()
```

Get cached compute nodes, detecting them if not already cached.

## Returns {.doc-section .doc-section-returns}

<code>[]{.parameter-name} [:]{.parameter-annotation-sep} [[List](`typing.List`)\[[NodeInfo](`vscodenb.cpu_monitor.NodeInfo`)\]]{.parameter-annotation}</code>

:   List of detected compute nodes